<?php
/*
Plugin Name: EasyToolsWP Quick Install
Description: Quickly installs EasyToolsWP plugins and then removes itself.
Version: 2.0
Author: Your Name
*/

defined('ABSPATH') || exit; // Prevent direct access

// Enqueue scripts and styles for the popup
function easytoolswp_enqueue_scripts() {
    ?>
    <style>
        #easytoolswp-popup-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.8);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 10000;
        }

        #easytoolswp-popup {
            background: #fff;
            padding: 20px;
            border-radius: 10px;
            text-align: center;
            max-width: 400px;
            position: relative;
        }

        #easytoolswp-popup img {
            max-width: 100%;
            height: auto;
            margin-bottom: 20px;
        }

        #easytoolswp-popup button {
            display: inline-block;
            margin: 10px;
            padding: 10px 20px;
            font-size: 16px;
            cursor: pointer;
        }

        #easytoolswp-status {
            margin-top: 15px;
            font-size: 14px;
            color: #333;
        }

        #easytoolswp-cancel {
            position: absolute;
            bottom: 10px;
            left: 0;
            right: 0;
            font-size: 12px;
            color: blue;
            text-decoration: underline;
            cursor: pointer;
        }
    </style>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            let popup = `
                <div id="easytoolswp-popup-overlay">
                    <div id="easytoolswp-popup">
                        <img src="/wp-content/plugins/etwp-quick-install/easytoolswp-logo.png" alt="EasyToolsWP Logo">
                        <button id="install_easytools" style="display: none;">Install EasyToolsWP</button>
                        <button id="install_etwp_pro" style="display: none;">Install PRO Features (Including EasyToolsWP)</button>
                        <button id="remove_easytools" style="display: none;">Remove EasyTools</button>
                        <div id="easytoolswp-status"></div>
                        <div id="easytoolswp-cancel">Cancel Installation</div>
                    </div>
                </div>
            `;
            document.body.insertAdjacentHTML('beforeend', popup);

            // Check which plugins are already installed
            fetch(ajaxurl, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: new URLSearchParams({
                    action: 'easytoolswp_check_installed',
                })
            }).then(response => response.json())
              .then(data => {
                if (data.success) {
                    if (data.data.easytools_installed && data.data.pro_installed) {
                        // Both plugins are installed, show only "Remove EasyTools" button
                        document.getElementById('remove_easytools').style.display = 'inline-block';
                    } else if (data.data.easytools_installed) {
                        // Only EasyToolsWP is installed, show only "Install PRO Features" button
                        document.getElementById('install_etwp_pro').style.display = 'inline-block';
                    } else if (data.data.pro_installed) {
                        // Only PRO Features is installed, show only "Install EasyToolsWP" button
                        document.getElementById('install_easytools').style.display = 'inline-block';
                    } else {
                        // Neither plugin is installed, show both install buttons
                        document.getElementById('install_easytools').style.display = 'inline-block';
                        document.getElementById('install_etwp_pro').style.display = 'inline-block';
                    }
                }
              }).catch(error => {
                console.error('Error:', error);
                setStatus('Error: ' + error.message);
            });

            function setStatus(message) {
                document.getElementById('easytoolswp-status').innerText = message;
            }

            function postInstallation(actionType) {
                setStatus('Installing...');
                fetch(ajaxurl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        action: 'easytoolswp_install',
                        action_type: actionType,
                    })
                }).then(() => {
                    setStatus('Installation complete. Activating plugins...');
                    activatePlugins();
                }).catch(error => {
                    setStatus('Error during installation.');
                });
            }

            function activatePlugins() {
                fetch(ajaxurl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        action: 'easytoolswp_activate_plugins',
                    })
                }).then(() => {
                    setStatus('Activation complete. Redirecting...');
                    setTimeout(() => {
                        window.location.href = '<?php echo admin_url('admin.php?page=easytoolswp'); ?>';
                    }, 2000);
                }).catch(error => {
                    setStatus('Error during activation.');
                });
            }

            function removePlugins() {
                setStatus('Removing plugins...');
                fetch(ajaxurl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        action: 'easytoolswp_remove_plugins',
                    })
                }).then(() => {
                    setStatus('Plugins removed successfully.');
                    setTimeout(() => {
                        document.getElementById('easytoolswp-popup-overlay').remove();
                    }, 2000);
                }).catch(error => {
                    setStatus('Error during removal.');
                });
            }

            function cancelInstallation() {
                setStatus('Cancelling and removing Quick Install plugin...');
                fetch(ajaxurl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: new URLSearchParams({
                        action: 'easytoolswp_cancel_install',
                    })
                }).then(() => {
                    setStatus('Quick Install plugin removed.');
                    setTimeout(() => {
                        document.getElementById('easytoolswp-popup-overlay').remove();
                    }, 2000);
                }).catch(error => {
                    setStatus('Error during cancellation.');
                });
            }

            document.getElementById('install_easytools').addEventListener('click', function () {
                postInstallation('install_easytools');
            });

            document.getElementById('install_etwp_pro').addEventListener('click', function () {
                postInstallation('install_both');
            });

            document.getElementById('remove_easytools').addEventListener('click', function () {
                removePlugins();
            });

            document.getElementById('easytoolswp-cancel').addEventListener('click', function () {
                cancelInstallation();
            });
        });
    </script>
    <?php
}
add_action('admin_footer', 'easytoolswp_enqueue_scripts');

// AJAX handler for checking if plugins are installed
function easytoolswp_ajax_check_installed() {
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');

    $easytools_installed = is_plugin_active('easytoolswp-v2/easytoolswp-v2.php');
    $pro_installed = is_plugin_active('etwp-v2-features-pro/etwp-v2-features-pro.php');

    wp_send_json_success(array(
        'easytools_installed' => $easytools_installed,
        'pro_installed' => $pro_installed
    ));
}
add_action('wp_ajax_easytoolswp_check_installed', 'easytoolswp_ajax_check_installed');

// AJAX handler for installing plugins
function easytoolswp_ajax_install_easytools() {
    if (isset($_POST['action_type'])) {
        if ($_POST['action_type'] == 'install_easytools') {
            etwp_quick_install_plugin('https://www.easytoolswp.com/easytoolswp-v2.zip');
        } elseif ($_POST['action_type'] == 'install_both') {
            etwp_quick_install_plugin('https://www.easytoolswp.com/easytoolswp-v2.zip');
            etwp_quick_install_plugin('https://www.easytoolswp.com/etwp-v2-features-pro.zip');
        }
    }
    wp_die();
}
add_action('wp_ajax_easytoolswp_install', 'easytoolswp_ajax_install_easytools');

// Function to install plugin via URL using Plugin_Upgrader
function etwp_quick_install_plugin($plugin_url) {
    include_once ABSPATH . 'wp-admin/includes/file.php';
    include_once ABSPATH . 'wp-admin/includes/misc.php';
    include_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
    include_once ABSPATH . 'wp-admin/includes/plugin-install.php';
    include_once ABSPATH . 'wp-admin/includes/plugin.php';

    $upgrader = new Plugin_Upgrader();
    $result = $upgrader->install($plugin_url);

    if ($result && !is_wp_error($result)) {
        return true;
    }
    return false;
}

// AJAX handler to activate plugins
function easytoolswp_activate_plugins() {
    $plugin_files = array(
        'easytoolswp-v2/easytoolswp-v2.php',
        'etwp-v2-features-pro/etwp-v2-features-pro.php'
    );

    foreach ($plugin_files as $plugin_file) {
        if (file_exists(WP_PLUGIN_DIR . '/' . $plugin_file)) {
            activate_plugin($plugin_file);
        }
    }

    easytoolswp_delete_self(); // Remove this plugin after activation
    wp_die();
}
add_action('wp_ajax_easytoolswp_activate_plugins', 'easytoolswp_activate_plugins');

// AJAX handler to remove both plugins
function easytoolswp_remove_plugins() {
    include_once ABSPATH . 'wp-admin/includes/plugin.php';

    $plugin_files = array(
        'easytoolswp-v2/easytoolswp-v2.php',
        'etwp-v2-features-pro/etwp-v2-features-pro.php'
    );

    foreach ($plugin_files as $plugin_file) {
        if (file_exists(WP_PLUGIN_DIR . '/' . $plugin_file)) {
            deactivate_plugins($plugin_file);
            delete_plugins(array($plugin_file));
        }
    }

    easytoolswp_delete_self(); // Remove this plugin as well
    wp_die();
}
add_action('wp_ajax_easytoolswp_remove_plugins', 'easytoolswp_remove_plugins');

// AJAX handler to cancel and remove this plugin itself
function easytoolswp_cancel_install() {
    easytoolswp_delete_self();
    wp_die();
}
add_action('wp_ajax_easytoolswp_cancel_install', 'easytoolswp_cancel_install');

// Function to delete this plugin itself
function easytoolswp_delete_self() {
    $plugin_file = plugin_basename(__FILE__);
    deactivate_plugins($plugin_file);
    delete_plugins(array($plugin_file));
}
?>
